from fabric.tools.lakehouse import lakehouse_lookup

def test_lakehouse_lookup():
    workspaceName = "ContosoTrek"
    artifactName = "contoso_customers"
    fileName = "customers.csv"
    params = {"customerId": "1"}

    customer = lakehouse_lookup(workspaceName, artifactName, fileName, params)
    assert customer["customerId"] == "1"
    assert customer["firstName"] == "John"
    assert customer["lastName"] == "Smith"


import yaml
from pathlib import Path


def collect_tools_from_directory(base_dir) -> dict:
    tools = {}
    for f in Path(base_dir).glob("**/*.yaml"):
        with open(f, "r") as f:
            tools_in_file = yaml.safe_load(f)
            for identifier, tool in tools_in_file.items():
                tools[identifier] = tool
    return tools


def list_package_tools():
    """List package tools"""
    yaml_dir = Path(__file__).parents[1] / "yamls"
    return collect_tools_from_directory(yaml_dir)


import json
from promptflow import tool
from azure.storage.filedatalake import (
    DataLakeServiceClient,
    DelimitedJsonDialect, 
    DelimitedTextDialect
)
from azure.identity import DefaultAzureCredential


@tool
def lakehouse_lookup(workspaceName: str, artifactName: str, fileName: str, params: dict[str, any]):
    storage_account_name = "dxt-onelake"
    artifact_type = "Lakehouse"

    token_credential = DefaultAzureCredential()
    service_client = DataLakeServiceClient(account_url=f"https://{storage_account_name}.dfs.fabric.microsoft.com", 
                                           credential=token_credential)
    file_system_client = service_client.get_file_system_client(file_system=workspaceName)
    file_client = file_system_client.get_file_client(f"{artifactName}.{artifact_type}/Files/{fileName}")

    query_expression = "SELECT * from DataLakeStorage"

    if params is not None and len(params) > 0:
        p = 0
        query_expression += " WHERE "
        for key, value in params.items():
            query_expression += f"{key} = " + (f"'{value}'" if isinstance(value, str) else f"{value}")
            if p < len(params) - 1:
                query_expression += " AND "
            p += 1

    input_format = DelimitedTextDialect(has_header=True)
    output_format = DelimitedJsonDialect(delimiter='\n')
    reader = file_client.query_file(query_expression, file_format=input_format, output_format=output_format)
    content = reader.readall()
    item = json.loads(content)
    return item



from setuptools import find_packages, setup

PACKAGE_NAME = "pffabric"

setup(
    name="pffabric",
    version="0.0.3",
    description="This package contains promptflow tools for working with Microsoft Fabric Lakehouse.",
    packages=find_packages(),
    entry_points={
        "package_tools": ["lakehouse = fabric.tools.utils:list_package_tools"],
    },
    include_package_data=True,   # This line tells setuptools to include files from MANIFEST.in
)